@@ -22,7 +22,7 @@ def image_to_tensor(image: Image, yolo_size: int = 608) -> np.ndarray:
     """
     image = image.resize((yolo_size, yolo_size), Image.BICUBIC)
     image = image.convert('RGB')
-    tensor = np.asarray(image)
+    tensor = np.asarray(image, dtype=np.float32)
     tensor = tensor / 255.0
     assert tensor.shape == (yolo_size, yolo_size, 3)
     return tensor
